@@ -15,6 +15,7 @@ Usage::
 from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
+from botocore.response import StreamingBody
 
 from .type_defs import InvokeEndpointOutputTypeDef
 
@@ -39,7 +40,7 @@ class Exceptions:
 
 class SageMakerRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
     """
 
@@ -48,7 +49,9 @@ class SageMakerRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#can_paginate)
         """
 
@@ -60,7 +63,9 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#generate_presigned_url)
         """
 
@@ -68,7 +73,7 @@ class SageMakerRuntimeClient:
         self,
         *,
         EndpointName: str,
-        Body: Union[bytes, IO[bytes]],
+        Body: Union[bytes, IO[bytes], StreamingBody],
         ContentType: str = None,
         Accept: str = None,
         CustomAttributes: str = None,
@@ -78,6 +83,10 @@ class SageMakerRuntimeClient:
         InferenceId: str = None
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        After you deploy a model into production using Amazon SageMaker hosting
+        services, your client applications use this API to get inferences from the model
+        hosted at the specified endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#invoke_endpoint)
         """
